GetConfig

Trait GetConfig 

pub trait GetConfig {
    type Config;

    // Required methods
    fn config(&self) -> &Self::Config;
    fn config_mut(&mut self) -> &mut Self::Config;
}
Allows to get mutable and immutable references to configuration options.

Required Associated Types

type Config

The configuration options type.

Required Methods

fn config(&self) -> &Self::Config

Returns an immutable reference to the configuration options used by self.

fn config_mut(&mut self) -> &mut Self::Config

Returns a mutable reference to the configuration options used by self.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors